import LicensePage from './licensing/LicensePage';
import ReportsList from './reports/ReportsListPage';
import ReportsSettings from './reports/ReportsSettingsPage';
import ReportPage from './reports/ReportPage';
import reportsReducers from './reports/state/reducers';
import { initReporting } from './reports';
import DataSourcePermissions from './permissions/DataSourcePermissions';
import { addRootReducer } from 'app/store/configureStore';
import dataSourcePermissionReducers from './permissions/state/reducers';
import { initWhitelabeling } from './whitelabeling';
import { config } from 'app/core/config';
import { initLicenseWarnings } from './licensing';
import { initMetaAnalytics } from './meta-analytics';
import { isExpired } from './utils';
import DataSourceInsights from './meta-analytics/DataSourceInsights/DataSourceInsights';
import metaAnalyticsReducers from './meta-analytics/state/reducers';
import { extraRoutes } from 'app/routes/routes';

function initEnterprise() {
  addRootReducer({ ...dataSourcePermissionReducers, ...reportsReducers, ...metaAnalyticsReducers });

  initWhitelabeling();
  initLicenseWarnings();
  initReporting();
  initMetaAnalytics();

  extraRoutes.push(
    ...[
      {
        path: '/datasources/edit/:id/permissions',
        component: DataSourcePermissions,
      },
      {
        path: '/reports',
        component: ReportsList,
      },
      {
        path: '/reports/edit/:id',
        component: ReportPage,
      },
      {
        path: '/reports/settings',
        component: ReportsSettings,
      },
      {
        path: '/datasources/edit/:id/insights',
        component: DataSourceInsights as any,
      },
    ]
  );

  if (!isExpired()) {
    extraRoutes.push({
      path: '/reports/new',
      component: ReportPage as any,
    });
  }
}

// initUnlicensed initialized features which are defined in Enterprise but
// should be available when running without a license.
function initUnlicensed() {
  extraRoutes.push({
    path: '/admin/licensing',
    roles: () => ['Admin'],
    component: LicensePage,
  });
}

export function init() {
  initUnlicensed();
  if (config.licenseInfo.hasLicense) {
    initEnterprise();
  }
}
